package com.ruoyi.system.service.impl;


import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.member.MemberInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.MemberInfoMapper;
import com.ruoyi.system.service.IMemberInfoService;

import java.util.List;

/**
 * 委员信息Service业务层处理
 * 
 * @author boman
 * @date 2024-03-07
 */
@Service
public class MemberInfoServiceImpl implements IMemberInfoService 
{
    @Autowired
    private MemberInfoMapper memberInfoMapper;

    /**
     * 查询委员信息
     * 
     * @param memberId 委员信息主键
     * @return 委员信息
     */
    @Override
    public MemberInfo selectMemberInfoByMemberId(Long memberId)
    {
        return memberInfoMapper.selectMemberInfoByMemberId(memberId);
    }

    /**
     * 查询委员信息列表
     * 
     * @param memberInfo 委员信息
     * @return 委员信息
     */
    @Override
    public List<MemberInfo> selectMemberInfoList(MemberInfo memberInfo)
    {
        return memberInfoMapper.selectMemberInfoList(memberInfo);
    }

    /**
     * 新增委员信息
     * 
     * @param memberInfo 委员信息
     * @return 结果
     */
    @Override
    public int insertMemberInfo(MemberInfo memberInfo)
    {
        memberInfo.setUserId(SecurityUtils.getUserId());
        memberInfo.setCreateTime(DateUtils.getNowDate());
        return memberInfoMapper.insertMemberInfo(memberInfo);
    }

    /**
     * 修改委员信息
     * 
     * @param memberInfo 委员信息
     * @return 结果
     */
    @Override
    public int updateMemberInfo(MemberInfo memberInfo)
    {
        memberInfo.setUpdateTime(DateUtils.getNowDate());
        return memberInfoMapper.updateMemberInfo(memberInfo);
    }

    /**
     * 批量删除委员信息
     * 
     * @param memberIds 需要删除的委员信息主键
     * @return 结果
     */
    @Override
    public int deleteMemberInfoByMemberIds(Long[] memberIds)
    {
        return memberInfoMapper.deleteMemberInfoByMemberIds(memberIds);
    }

    /**
     * 删除委员信息信息
     * 
     * @param memberId 委员信息主键
     * @return 结果
     */
    @Override
    public int deleteMemberInfoByMemberId(Long memberId)
    {
        return memberInfoMapper.deleteMemberInfoByMemberId(memberId);
    }
}
